# qdrant_openapi
API description for Qdrant vector search engine.

This document describes CRUD and search operations on collections of points (vectors with payload).

Qdrant supports any combinations of `should`, `must` and `must_not` conditions, which makes it possible to use in applications when object could not be described solely by vector. It could be location features, availability flags, and other custom properties businesses should take into account.
## Examples
This examples cover the most basic use-cases - collection creation and basic vector search.
### Create collection
First - let's create a collection with dot-production metric.
```
curl -X PUT 'http://localhost:6333/collections/test_collection' \\
  -H 'Content-Type: application/json' \\
  --data-raw '{
    \"vectors\": {
      \"size\": 4,
      \"distance\": \"Dot\"
    }
  }'

```
Expected response:
```
{
    \"result\": true,
    \"status\": \"ok\",
    \"time\": 0.031095451
}
```
We can ensure that collection was created:
```
curl 'http://localhost:6333/collections/test_collection'
```
Expected response:
```
{
  \"result\": {
    \"status\": \"green\",
    \"vectors_count\": 0,
    \"segments_count\": 5,
    \"disk_data_size\": 0,
    \"ram_data_size\": 0,
    \"config\": {
      \"params\": {
        \"vectors\": {
          \"size\": 4,
          \"distance\": \"Dot\"
        }
      },
      \"hnsw_config\": {
        \"m\": 16,
        \"ef_construct\": 100,
        \"full_scan_threshold\": 10000
      },
      \"optimizer_config\": {
        \"deleted_threshold\": 0.2,
        \"vacuum_min_vector_number\": 1000,
        \"max_segment_number\": 5,
        \"memmap_threshold\": 50000,
        \"indexing_threshold\": 20000,
        \"flush_interval_sec\": 1
      },
      \"wal_config\": {
        \"wal_capacity_mb\": 32,
        \"wal_segments_ahead\": 0
      }
    }
  },
  \"status\": \"ok\",
  \"time\": 2.1199e-05
}
```

### Add points
Let's now add vectors with some payload:
```
curl -L -X PUT 'http://localhost:6333/collections/test_collection/points?wait=true' \\ -H 'Content-Type: application/json' \\ --data-raw '{
  \"points\": [
    {\"id\": 1, \"vector\": [0.05, 0.61, 0.76, 0.74], \"payload\": {\"city\": \"Berlin\"}},
    {\"id\": 2, \"vector\": [0.19, 0.81, 0.75, 0.11], \"payload\": {\"city\": [\"Berlin\", \"London\"] }},
    {\"id\": 3, \"vector\": [0.36, 0.55, 0.47, 0.94], \"payload\": {\"city\": [\"Berlin\", \"Moscow\"] }},
    {\"id\": 4, \"vector\": [0.18, 0.01, 0.85, 0.80], \"payload\": {\"city\": [\"London\", \"Moscow\"] }},
    {\"id\": 5, \"vector\": [0.24, 0.18, 0.22, 0.44], \"payload\": {\"count\": [0]}},
    {\"id\": 6, \"vector\": [0.35, 0.08, 0.11, 0.44]}
  ]
}'
```
Expected response:
```
{
    \"result\": {
        \"operation_id\": 0,
        \"status\": \"completed\"
    },
    \"status\": \"ok\",
    \"time\": 0.000206061
}
```
### Search with filtering
Let's start with a basic request:
```
curl -L -X POST 'http://localhost:6333/collections/test_collection/points/search' \\ -H 'Content-Type: application/json' \\ --data-raw '{
    \"vector\": [0.2,0.1,0.9,0.7],
    \"top\": 3
}'
```
Expected response:
```
{
    \"result\": [
        { \"id\": 4, \"score\": 1.362, \"payload\": null, \"version\": 0 },
        { \"id\": 1, \"score\": 1.273, \"payload\": null, \"version\": 0 },
        { \"id\": 3, \"score\": 1.208, \"payload\": null, \"version\": 0 }
    ],
    \"status\": \"ok\",
    \"time\": 0.000055785
}
```
But result is different if we add a filter:
```
curl -L -X POST 'http://localhost:6333/collections/test_collection/points/search' \\ -H 'Content-Type: application/json' \\ --data-raw '{
    \"filter\": {
        \"should\": [
            {
                \"key\": \"city\",
                \"match\": {
                    \"value\": \"London\"
                }
            }
        ]
    },
    \"vector\": [0.2, 0.1, 0.9, 0.7],
    \"top\": 3
}'
```
Expected response:
```
{
    \"result\": [
        { \"id\": 4, \"score\": 1.362, \"payload\": null, \"version\": 0 },
        { \"id\": 2, \"score\": 0.871, \"payload\": null, \"version\": 0 }
    ],
    \"status\": \"ok\",
    \"time\": 0.000093972
}
```


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1.7.x
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import qdrant_openapi
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import qdrant_openapi
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import qdrant_openapi
from pprint import pprint
from qdrant_openapi.api import cluster_api
from qdrant_openapi.model.cluster_operations import ClusterOperations
from qdrant_openapi.model.create_sharding_key import CreateShardingKey
from qdrant_openapi.model.drop_sharding_key import DropShardingKey
from qdrant_openapi.model.error_response import ErrorResponse
from qdrant_openapi.model.inline_response200 import InlineResponse200
from qdrant_openapi.model.inline_response2003 import InlineResponse2003
from qdrant_openapi.model.inline_response2007 import InlineResponse2007
# Defining the host is optional and defaults to http://localhost:6333
# See configuration.py for a list of all supported configuration parameters.
configuration = qdrant_openapi.Configuration(
    host = "http://localhost:6333"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: api-key
configuration.api_key['api-key'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['api-key'] = 'Bearer'

# Configure Bearer authorization: bearerAuth
configuration = qdrant_openapi.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with qdrant_openapi.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = cluster_api.ClusterApi(api_client)
    
    try:
        # Get cluster status info
        api_response = api_instance.cluster_status()
        pprint(api_response)
    except qdrant_openapi.ApiException as e:
        print("Exception when calling ClusterApi->cluster_status: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:6333*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ClusterApi* | [**cluster_status**](docs/ClusterApi.md#cluster_status) | **GET** /cluster | Get cluster status info
*ClusterApi* | [**collection_cluster_info**](docs/ClusterApi.md#collection_cluster_info) | **GET** /collections/{collection_name}/cluster | Collection cluster info
*ClusterApi* | [**create_shard_key**](docs/ClusterApi.md#create_shard_key) | **PUT** /collections/{collection_name}/shards | Create shard key
*ClusterApi* | [**delete_shard_key**](docs/ClusterApi.md#delete_shard_key) | **POST** /collections/{collection_name}/shards/delete | Delete shard key
*ClusterApi* | [**recover_current_peer**](docs/ClusterApi.md#recover_current_peer) | **POST** /cluster/recover | Tries to recover current peer Raft state.
*ClusterApi* | [**remove_peer**](docs/ClusterApi.md#remove_peer) | **DELETE** /cluster/peer/{peer_id} | Remove peer from the cluster
*ClusterApi* | [**update_collection_cluster**](docs/ClusterApi.md#update_collection_cluster) | **POST** /collections/{collection_name}/cluster | Update collection cluster setup
*CollectionsApi* | [**collection_cluster_info**](docs/CollectionsApi.md#collection_cluster_info) | **GET** /collections/{collection_name}/cluster | Collection cluster info
*CollectionsApi* | [**create_collection**](docs/CollectionsApi.md#create_collection) | **PUT** /collections/{collection_name} | Create collection
*CollectionsApi* | [**create_field_index**](docs/CollectionsApi.md#create_field_index) | **PUT** /collections/{collection_name}/index | Create index for field in collection
*CollectionsApi* | [**create_shard_key**](docs/CollectionsApi.md#create_shard_key) | **PUT** /collections/{collection_name}/shards | Create shard key
*CollectionsApi* | [**create_shard_snapshot**](docs/CollectionsApi.md#create_shard_snapshot) | **POST** /collections/{collection_name}/shards/{shard_id}/snapshots | Create shard snapshot
*CollectionsApi* | [**create_snapshot**](docs/CollectionsApi.md#create_snapshot) | **POST** /collections/{collection_name}/snapshots | Create collection snapshot
*CollectionsApi* | [**delete_collection**](docs/CollectionsApi.md#delete_collection) | **DELETE** /collections/{collection_name} | Delete collection
*CollectionsApi* | [**delete_field_index**](docs/CollectionsApi.md#delete_field_index) | **DELETE** /collections/{collection_name}/index/{field_name} | Delete index for field in collection
*CollectionsApi* | [**delete_shard_key**](docs/CollectionsApi.md#delete_shard_key) | **POST** /collections/{collection_name}/shards/delete | Delete shard key
*CollectionsApi* | [**delete_shard_snapshot**](docs/CollectionsApi.md#delete_shard_snapshot) | **DELETE** /collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name} | Delete shard snapshot
*CollectionsApi* | [**delete_snapshot**](docs/CollectionsApi.md#delete_snapshot) | **DELETE** /collections/{collection_name}/snapshots/{snapshot_name} | Delete collection snapshot
*CollectionsApi* | [**get_collection**](docs/CollectionsApi.md#get_collection) | **GET** /collections/{collection_name} | Collection info
*CollectionsApi* | [**get_collection_aliases**](docs/CollectionsApi.md#get_collection_aliases) | **GET** /collections/{collection_name}/aliases | List aliases for collection
*CollectionsApi* | [**get_collections**](docs/CollectionsApi.md#get_collections) | **GET** /collections | List collections
*CollectionsApi* | [**get_collections_aliases**](docs/CollectionsApi.md#get_collections_aliases) | **GET** /aliases | List collections aliases
*CollectionsApi* | [**get_shard_snapshot**](docs/CollectionsApi.md#get_shard_snapshot) | **GET** /collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name} | Download collection snapshot
*CollectionsApi* | [**get_snapshot**](docs/CollectionsApi.md#get_snapshot) | **GET** /collections/{collection_name}/snapshots/{snapshot_name} | Download collection snapshot
*CollectionsApi* | [**list_shard_snapshots**](docs/CollectionsApi.md#list_shard_snapshots) | **GET** /collections/{collection_name}/shards/{shard_id}/snapshots | List shards snapshots for a collection
*CollectionsApi* | [**list_snapshots**](docs/CollectionsApi.md#list_snapshots) | **GET** /collections/{collection_name}/snapshots | List collection snapshots
*CollectionsApi* | [**recover_from_snapshot**](docs/CollectionsApi.md#recover_from_snapshot) | **PUT** /collections/{collection_name}/snapshots/recover | Recover from a snapshot
*CollectionsApi* | [**recover_from_uploaded_snapshot**](docs/CollectionsApi.md#recover_from_uploaded_snapshot) | **POST** /collections/{collection_name}/snapshots/upload | Recover from an uploaded snapshot
*CollectionsApi* | [**recover_shard_from_snapshot**](docs/CollectionsApi.md#recover_shard_from_snapshot) | **PUT** /collections/{collection_name}/shards/{shard_id}/snapshots/recover | Recover from a snapshot
*CollectionsApi* | [**recover_shard_from_uploaded_snapshot**](docs/CollectionsApi.md#recover_shard_from_uploaded_snapshot) | **POST** /collections/{collection_name}/shards/{shard_id}/snapshots/upload | Recover shard from an uploaded snapshot
*CollectionsApi* | [**update_aliases**](docs/CollectionsApi.md#update_aliases) | **POST** /collections/aliases | Update aliases of the collections
*CollectionsApi* | [**update_collection**](docs/CollectionsApi.md#update_collection) | **PATCH** /collections/{collection_name} | Update collection parameters
*CollectionsApi* | [**update_collection_cluster**](docs/CollectionsApi.md#update_collection_cluster) | **POST** /collections/{collection_name}/cluster | Update collection cluster setup
*PointsApi* | [**batch_update**](docs/PointsApi.md#batch_update) | **POST** /collections/{collection_name}/points/batch | Batch update points
*PointsApi* | [**clear_payload**](docs/PointsApi.md#clear_payload) | **POST** /collections/{collection_name}/points/payload/clear | Clear payload
*PointsApi* | [**count_points**](docs/PointsApi.md#count_points) | **POST** /collections/{collection_name}/points/count | Count points
*PointsApi* | [**delete_payload**](docs/PointsApi.md#delete_payload) | **POST** /collections/{collection_name}/points/payload/delete | Delete payload
*PointsApi* | [**delete_points**](docs/PointsApi.md#delete_points) | **POST** /collections/{collection_name}/points/delete | Delete points
*PointsApi* | [**delete_vectors**](docs/PointsApi.md#delete_vectors) | **POST** /collections/{collection_name}/points/vectors/delete | Delete vectors
*PointsApi* | [**discover_batch_points**](docs/PointsApi.md#discover_batch_points) | **POST** /collections/{collection_name}/points/discover/batch | Discover batch points
*PointsApi* | [**discover_points**](docs/PointsApi.md#discover_points) | **POST** /collections/{collection_name}/points/discover | Discover points
*PointsApi* | [**get_point**](docs/PointsApi.md#get_point) | **GET** /collections/{collection_name}/points/{id} | Get point
*PointsApi* | [**get_points**](docs/PointsApi.md#get_points) | **POST** /collections/{collection_name}/points | Get points
*PointsApi* | [**overwrite_payload**](docs/PointsApi.md#overwrite_payload) | **PUT** /collections/{collection_name}/points/payload | Overwrite payload
*PointsApi* | [**recommend_batch_points**](docs/PointsApi.md#recommend_batch_points) | **POST** /collections/{collection_name}/points/recommend/batch | Recommend batch points
*PointsApi* | [**recommend_point_groups**](docs/PointsApi.md#recommend_point_groups) | **POST** /collections/{collection_name}/points/recommend/groups | Recommend point groups
*PointsApi* | [**recommend_points**](docs/PointsApi.md#recommend_points) | **POST** /collections/{collection_name}/points/recommend | Recommend points
*PointsApi* | [**scroll_points**](docs/PointsApi.md#scroll_points) | **POST** /collections/{collection_name}/points/scroll | Scroll points
*PointsApi* | [**search_batch_points**](docs/PointsApi.md#search_batch_points) | **POST** /collections/{collection_name}/points/search/batch | Search batch points
*PointsApi* | [**search_point_groups**](docs/PointsApi.md#search_point_groups) | **POST** /collections/{collection_name}/points/search/groups | Search point groups
*PointsApi* | [**search_points**](docs/PointsApi.md#search_points) | **POST** /collections/{collection_name}/points/search | Search points
*PointsApi* | [**set_payload**](docs/PointsApi.md#set_payload) | **POST** /collections/{collection_name}/points/payload | Set payload
*PointsApi* | [**update_vectors**](docs/PointsApi.md#update_vectors) | **PUT** /collections/{collection_name}/points/vectors | Update vectors
*PointsApi* | [**upsert_points**](docs/PointsApi.md#upsert_points) | **PUT** /collections/{collection_name}/points | Upsert points
*ServiceApi* | [**get_locks**](docs/ServiceApi.md#get_locks) | **GET** /locks | Get lock options
*ServiceApi* | [**healthz**](docs/ServiceApi.md#healthz) | **GET** /healthz | Kubernetes healthz endpoint
*ServiceApi* | [**livez**](docs/ServiceApi.md#livez) | **GET** /livez | Kubernetes livez endpoint
*ServiceApi* | [**metrics**](docs/ServiceApi.md#metrics) | **GET** /metrics | Collect Prometheus metrics data
*ServiceApi* | [**post_locks**](docs/ServiceApi.md#post_locks) | **POST** /locks | Set lock options
*ServiceApi* | [**readyz**](docs/ServiceApi.md#readyz) | **GET** /readyz | Kubernetes readyz endpoint
*ServiceApi* | [**telemetry**](docs/ServiceApi.md#telemetry) | **GET** /telemetry | Collect telemetry data
*SnapshotsApi* | [**create_full_snapshot**](docs/SnapshotsApi.md#create_full_snapshot) | **POST** /snapshots | Create storage snapshot
*SnapshotsApi* | [**create_shard_snapshot**](docs/SnapshotsApi.md#create_shard_snapshot) | **POST** /collections/{collection_name}/shards/{shard_id}/snapshots | Create shard snapshot
*SnapshotsApi* | [**create_snapshot**](docs/SnapshotsApi.md#create_snapshot) | **POST** /collections/{collection_name}/snapshots | Create collection snapshot
*SnapshotsApi* | [**delete_full_snapshot**](docs/SnapshotsApi.md#delete_full_snapshot) | **DELETE** /snapshots/{snapshot_name} | Delete storage snapshot
*SnapshotsApi* | [**delete_shard_snapshot**](docs/SnapshotsApi.md#delete_shard_snapshot) | **DELETE** /collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name} | Delete shard snapshot
*SnapshotsApi* | [**delete_snapshot**](docs/SnapshotsApi.md#delete_snapshot) | **DELETE** /collections/{collection_name}/snapshots/{snapshot_name} | Delete collection snapshot
*SnapshotsApi* | [**get_full_snapshot**](docs/SnapshotsApi.md#get_full_snapshot) | **GET** /snapshots/{snapshot_name} | Download storage snapshot
*SnapshotsApi* | [**get_shard_snapshot**](docs/SnapshotsApi.md#get_shard_snapshot) | **GET** /collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name} | Download collection snapshot
*SnapshotsApi* | [**get_snapshot**](docs/SnapshotsApi.md#get_snapshot) | **GET** /collections/{collection_name}/snapshots/{snapshot_name} | Download collection snapshot
*SnapshotsApi* | [**list_full_snapshots**](docs/SnapshotsApi.md#list_full_snapshots) | **GET** /snapshots | List of storage snapshots
*SnapshotsApi* | [**list_shard_snapshots**](docs/SnapshotsApi.md#list_shard_snapshots) | **GET** /collections/{collection_name}/shards/{shard_id}/snapshots | List shards snapshots for a collection
*SnapshotsApi* | [**list_snapshots**](docs/SnapshotsApi.md#list_snapshots) | **GET** /collections/{collection_name}/snapshots | List collection snapshots
*SnapshotsApi* | [**recover_from_snapshot**](docs/SnapshotsApi.md#recover_from_snapshot) | **PUT** /collections/{collection_name}/snapshots/recover | Recover from a snapshot
*SnapshotsApi* | [**recover_from_uploaded_snapshot**](docs/SnapshotsApi.md#recover_from_uploaded_snapshot) | **POST** /collections/{collection_name}/snapshots/upload | Recover from an uploaded snapshot
*SnapshotsApi* | [**recover_shard_from_snapshot**](docs/SnapshotsApi.md#recover_shard_from_snapshot) | **PUT** /collections/{collection_name}/shards/{shard_id}/snapshots/recover | Recover from a snapshot
*SnapshotsApi* | [**recover_shard_from_uploaded_snapshot**](docs/SnapshotsApi.md#recover_shard_from_uploaded_snapshot) | **POST** /collections/{collection_name}/shards/{shard_id}/snapshots/upload | Recover shard from an uploaded snapshot


## Documentation For Models

 - [AbortTransferOperation](docs/AbortTransferOperation.md)
 - [AliasDescription](docs/AliasDescription.md)
 - [AliasOperations](docs/AliasOperations.md)
 - [AnyVariants](docs/AnyVariants.md)
 - [AppBuildTelemetry](docs/AppBuildTelemetry.md)
 - [AppFeaturesTelemetry](docs/AppFeaturesTelemetry.md)
 - [Batch](docs/Batch.md)
 - [BatchVectorStruct](docs/BatchVectorStruct.md)
 - [BinaryQuantization](docs/BinaryQuantization.md)
 - [BinaryQuantizationConfig](docs/BinaryQuantizationConfig.md)
 - [ChangeAliasesOperation](docs/ChangeAliasesOperation.md)
 - [ClearPayloadOperation](docs/ClearPayloadOperation.md)
 - [ClusterConfigTelemetry](docs/ClusterConfigTelemetry.md)
 - [ClusterOperations](docs/ClusterOperations.md)
 - [ClusterStatus](docs/ClusterStatus.md)
 - [ClusterStatusOneOf](docs/ClusterStatusOneOf.md)
 - [ClusterStatusOneOf1](docs/ClusterStatusOneOf1.md)
 - [ClusterStatusTelemetry](docs/ClusterStatusTelemetry.md)
 - [ClusterTelemetry](docs/ClusterTelemetry.md)
 - [CollectionClusterInfo](docs/CollectionClusterInfo.md)
 - [CollectionConfig](docs/CollectionConfig.md)
 - [CollectionDescription](docs/CollectionDescription.md)
 - [CollectionInfo](docs/CollectionInfo.md)
 - [CollectionParams](docs/CollectionParams.md)
 - [CollectionParamsDiff](docs/CollectionParamsDiff.md)
 - [CollectionStatus](docs/CollectionStatus.md)
 - [CollectionTelemetry](docs/CollectionTelemetry.md)
 - [CollectionTelemetryEnum](docs/CollectionTelemetryEnum.md)
 - [CollectionsAggregatedTelemetry](docs/CollectionsAggregatedTelemetry.md)
 - [CollectionsAliasesResponse](docs/CollectionsAliasesResponse.md)
 - [CollectionsResponse](docs/CollectionsResponse.md)
 - [CollectionsTelemetry](docs/CollectionsTelemetry.md)
 - [CompressionRatio](docs/CompressionRatio.md)
 - [Condition](docs/Condition.md)
 - [ConsensusConfigTelemetry](docs/ConsensusConfigTelemetry.md)
 - [ConsensusThreadStatus](docs/ConsensusThreadStatus.md)
 - [ConsensusThreadStatusOneOf](docs/ConsensusThreadStatusOneOf.md)
 - [ConsensusThreadStatusOneOf1](docs/ConsensusThreadStatusOneOf1.md)
 - [ConsensusThreadStatusOneOf2](docs/ConsensusThreadStatusOneOf2.md)
 - [ContextExamplePair](docs/ContextExamplePair.md)
 - [CountRequest](docs/CountRequest.md)
 - [CountResult](docs/CountResult.md)
 - [CreateAlias](docs/CreateAlias.md)
 - [CreateAliasOperation](docs/CreateAliasOperation.md)
 - [CreateCollection](docs/CreateCollection.md)
 - [CreateFieldIndex](docs/CreateFieldIndex.md)
 - [CreateShardingKey](docs/CreateShardingKey.md)
 - [CreateShardingKeyOperation](docs/CreateShardingKeyOperation.md)
 - [DeleteAlias](docs/DeleteAlias.md)
 - [DeleteAliasOperation](docs/DeleteAliasOperation.md)
 - [DeleteOperation](docs/DeleteOperation.md)
 - [DeletePayload](docs/DeletePayload.md)
 - [DeletePayloadOperation](docs/DeletePayloadOperation.md)
 - [DeleteVectors](docs/DeleteVectors.md)
 - [DeleteVectorsOperation](docs/DeleteVectorsOperation.md)
 - [Disabled](docs/Disabled.md)
 - [DiscoverRequest](docs/DiscoverRequest.md)
 - [DiscoverRequestBatch](docs/DiscoverRequestBatch.md)
 - [Distance](docs/Distance.md)
 - [DropReplicaOperation](docs/DropReplicaOperation.md)
 - [DropShardingKey](docs/DropShardingKey.md)
 - [DropShardingKeyOperation](docs/DropShardingKeyOperation.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [ErrorResponseStatus](docs/ErrorResponseStatus.md)
 - [ExtendedPointId](docs/ExtendedPointId.md)
 - [FieldCondition](docs/FieldCondition.md)
 - [Filter](docs/Filter.md)
 - [FilterSelector](docs/FilterSelector.md)
 - [GeoBoundingBox](docs/GeoBoundingBox.md)
 - [GeoLineString](docs/GeoLineString.md)
 - [GeoPoint](docs/GeoPoint.md)
 - [GeoPolygon](docs/GeoPolygon.md)
 - [GeoRadius](docs/GeoRadius.md)
 - [GroupId](docs/GroupId.md)
 - [GroupsResult](docs/GroupsResult.md)
 - [GrpcTelemetry](docs/GrpcTelemetry.md)
 - [HasIdCondition](docs/HasIdCondition.md)
 - [HnswConfig](docs/HnswConfig.md)
 - [HnswConfigDiff](docs/HnswConfigDiff.md)
 - [Indexes](docs/Indexes.md)
 - [IndexesOneOf](docs/IndexesOneOf.md)
 - [IndexesOneOf1](docs/IndexesOneOf1.md)
 - [InitFrom](docs/InitFrom.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse20010](docs/InlineResponse20010.md)
 - [InlineResponse20011](docs/InlineResponse20011.md)
 - [InlineResponse20012](docs/InlineResponse20012.md)
 - [InlineResponse20013](docs/InlineResponse20013.md)
 - [InlineResponse20014](docs/InlineResponse20014.md)
 - [InlineResponse20015](docs/InlineResponse20015.md)
 - [InlineResponse20016](docs/InlineResponse20016.md)
 - [InlineResponse20017](docs/InlineResponse20017.md)
 - [InlineResponse20018](docs/InlineResponse20018.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse2003](docs/InlineResponse2003.md)
 - [InlineResponse2004](docs/InlineResponse2004.md)
 - [InlineResponse2005](docs/InlineResponse2005.md)
 - [InlineResponse2006](docs/InlineResponse2006.md)
 - [InlineResponse2007](docs/InlineResponse2007.md)
 - [InlineResponse2008](docs/InlineResponse2008.md)
 - [InlineResponse2009](docs/InlineResponse2009.md)
 - [InlineResponse202](docs/InlineResponse202.md)
 - [IsEmptyCondition](docs/IsEmptyCondition.md)
 - [IsNullCondition](docs/IsNullCondition.md)
 - [LocalShardInfo](docs/LocalShardInfo.md)
 - [LocalShardTelemetry](docs/LocalShardTelemetry.md)
 - [LocksOption](docs/LocksOption.md)
 - [LookupLocation](docs/LookupLocation.md)
 - [Match](docs/Match.md)
 - [MatchAny](docs/MatchAny.md)
 - [MatchExcept](docs/MatchExcept.md)
 - [MatchText](docs/MatchText.md)
 - [MatchValue](docs/MatchValue.md)
 - [MessageSendErrors](docs/MessageSendErrors.md)
 - [MoveShard](docs/MoveShard.md)
 - [MoveShardOperation](docs/MoveShardOperation.md)
 - [NamedSparseVector](docs/NamedSparseVector.md)
 - [NamedVector](docs/NamedVector.md)
 - [NamedVectorStruct](docs/NamedVectorStruct.md)
 - [Nested](docs/Nested.md)
 - [NestedCondition](docs/NestedCondition.md)
 - [OperationDurationStatistics](docs/OperationDurationStatistics.md)
 - [OptimizerTelemetry](docs/OptimizerTelemetry.md)
 - [OptimizersConfig](docs/OptimizersConfig.md)
 - [OptimizersConfigDiff](docs/OptimizersConfigDiff.md)
 - [OptimizersStatus](docs/OptimizersStatus.md)
 - [OptimizersStatusOneOf](docs/OptimizersStatusOneOf.md)
 - [OptimizersStatusOneOf1](docs/OptimizersStatusOneOf1.md)
 - [OverwritePayloadOperation](docs/OverwritePayloadOperation.md)
 - [P2pConfigTelemetry](docs/P2pConfigTelemetry.md)
 - [Payload](docs/Payload.md)
 - [PayloadField](docs/PayloadField.md)
 - [PayloadFieldSchema](docs/PayloadFieldSchema.md)
 - [PayloadIndexInfo](docs/PayloadIndexInfo.md)
 - [PayloadIndexTelemetry](docs/PayloadIndexTelemetry.md)
 - [PayloadSchemaParams](docs/PayloadSchemaParams.md)
 - [PayloadSchemaType](docs/PayloadSchemaType.md)
 - [PayloadSelector](docs/PayloadSelector.md)
 - [PayloadSelectorExclude](docs/PayloadSelectorExclude.md)
 - [PayloadSelectorInclude](docs/PayloadSelectorInclude.md)
 - [PayloadStorageType](docs/PayloadStorageType.md)
 - [PayloadStorageTypeOneOf](docs/PayloadStorageTypeOneOf.md)
 - [PayloadStorageTypeOneOf1](docs/PayloadStorageTypeOneOf1.md)
 - [PeerInfo](docs/PeerInfo.md)
 - [PointGroup](docs/PointGroup.md)
 - [PointIdsList](docs/PointIdsList.md)
 - [PointInsertOperations](docs/PointInsertOperations.md)
 - [PointRequest](docs/PointRequest.md)
 - [PointStruct](docs/PointStruct.md)
 - [PointVectors](docs/PointVectors.md)
 - [PointsBatch](docs/PointsBatch.md)
 - [PointsList](docs/PointsList.md)
 - [PointsSelector](docs/PointsSelector.md)
 - [ProductQuantization](docs/ProductQuantization.md)
 - [ProductQuantizationConfig](docs/ProductQuantizationConfig.md)
 - [QuantizationConfig](docs/QuantizationConfig.md)
 - [QuantizationConfigDiff](docs/QuantizationConfigDiff.md)
 - [QuantizationSearchParams](docs/QuantizationSearchParams.md)
 - [RaftInfo](docs/RaftInfo.md)
 - [Range](docs/Range.md)
 - [ReadConsistency](docs/ReadConsistency.md)
 - [ReadConsistencyType](docs/ReadConsistencyType.md)
 - [RecommendExample](docs/RecommendExample.md)
 - [RecommendGroupsRequest](docs/RecommendGroupsRequest.md)
 - [RecommendRequest](docs/RecommendRequest.md)
 - [RecommendRequestBatch](docs/RecommendRequestBatch.md)
 - [RecommendStrategy](docs/RecommendStrategy.md)
 - [Record](docs/Record.md)
 - [RemoteShardInfo](docs/RemoteShardInfo.md)
 - [RemoteShardTelemetry](docs/RemoteShardTelemetry.md)
 - [RenameAlias](docs/RenameAlias.md)
 - [RenameAliasOperation](docs/RenameAliasOperation.md)
 - [Replica](docs/Replica.md)
 - [ReplicaSetTelemetry](docs/ReplicaSetTelemetry.md)
 - [ReplicaState](docs/ReplicaState.md)
 - [ReplicateShardOperation](docs/ReplicateShardOperation.md)
 - [RequestsTelemetry](docs/RequestsTelemetry.md)
 - [RunningEnvironmentTelemetry](docs/RunningEnvironmentTelemetry.md)
 - [ScalarQuantization](docs/ScalarQuantization.md)
 - [ScalarQuantizationConfig](docs/ScalarQuantizationConfig.md)
 - [ScalarType](docs/ScalarType.md)
 - [ScoredPoint](docs/ScoredPoint.md)
 - [ScrollRequest](docs/ScrollRequest.md)
 - [ScrollResult](docs/ScrollResult.md)
 - [SearchGroupsRequest](docs/SearchGroupsRequest.md)
 - [SearchParams](docs/SearchParams.md)
 - [SearchRequest](docs/SearchRequest.md)
 - [SearchRequestBatch](docs/SearchRequestBatch.md)
 - [SegmentConfig](docs/SegmentConfig.md)
 - [SegmentInfo](docs/SegmentInfo.md)
 - [SegmentTelemetry](docs/SegmentTelemetry.md)
 - [SegmentType](docs/SegmentType.md)
 - [SetPayload](docs/SetPayload.md)
 - [SetPayloadOperation](docs/SetPayloadOperation.md)
 - [ShardKey](docs/ShardKey.md)
 - [ShardKeySelector](docs/ShardKeySelector.md)
 - [ShardSnapshotLocation](docs/ShardSnapshotLocation.md)
 - [ShardSnapshotRecover](docs/ShardSnapshotRecover.md)
 - [ShardTransferInfo](docs/ShardTransferInfo.md)
 - [ShardTransferMethod](docs/ShardTransferMethod.md)
 - [ShardTransferMethodOneOf](docs/ShardTransferMethodOneOf.md)
 - [ShardTransferMethodOneOf1](docs/ShardTransferMethodOneOf1.md)
 - [ShardingMethod](docs/ShardingMethod.md)
 - [SnapshotDescription](docs/SnapshotDescription.md)
 - [SnapshotPriority](docs/SnapshotPriority.md)
 - [SnapshotRecover](docs/SnapshotRecover.md)
 - [SparseIndexConfig](docs/SparseIndexConfig.md)
 - [SparseIndexParams](docs/SparseIndexParams.md)
 - [SparseIndexType](docs/SparseIndexType.md)
 - [SparseIndexTypeOneOf](docs/SparseIndexTypeOneOf.md)
 - [SparseIndexTypeOneOf1](docs/SparseIndexTypeOneOf1.md)
 - [SparseIndexTypeOneOf2](docs/SparseIndexTypeOneOf2.md)
 - [SparseVector](docs/SparseVector.md)
 - [SparseVectorDataConfig](docs/SparseVectorDataConfig.md)
 - [SparseVectorParams](docs/SparseVectorParams.md)
 - [SparseVectorsConfig](docs/SparseVectorsConfig.md)
 - [StateRole](docs/StateRole.md)
 - [TelemetryData](docs/TelemetryData.md)
 - [TextIndexParams](docs/TextIndexParams.md)
 - [TextIndexType](docs/TextIndexType.md)
 - [TokenizerType](docs/TokenizerType.md)
 - [TrackerStatus](docs/TrackerStatus.md)
 - [TrackerStatusOneOf](docs/TrackerStatusOneOf.md)
 - [TrackerStatusOneOf1](docs/TrackerStatusOneOf1.md)
 - [TrackerStatusOneOf2](docs/TrackerStatusOneOf2.md)
 - [TrackerTelemetry](docs/TrackerTelemetry.md)
 - [UpdateCollection](docs/UpdateCollection.md)
 - [UpdateOperation](docs/UpdateOperation.md)
 - [UpdateOperations](docs/UpdateOperations.md)
 - [UpdateResult](docs/UpdateResult.md)
 - [UpdateStatus](docs/UpdateStatus.md)
 - [UpdateVectors](docs/UpdateVectors.md)
 - [UpdateVectorsOperation](docs/UpdateVectorsOperation.md)
 - [UpsertOperation](docs/UpsertOperation.md)
 - [UsingVector](docs/UsingVector.md)
 - [ValueVariants](docs/ValueVariants.md)
 - [ValuesCount](docs/ValuesCount.md)
 - [Vector](docs/Vector.md)
 - [VectorDataConfig](docs/VectorDataConfig.md)
 - [VectorDataInfo](docs/VectorDataInfo.md)
 - [VectorIndexSearchesTelemetry](docs/VectorIndexSearchesTelemetry.md)
 - [VectorParams](docs/VectorParams.md)
 - [VectorParamsDiff](docs/VectorParamsDiff.md)
 - [VectorStorageType](docs/VectorStorageType.md)
 - [VectorStorageTypeOneOf](docs/VectorStorageTypeOneOf.md)
 - [VectorStorageTypeOneOf1](docs/VectorStorageTypeOneOf1.md)
 - [VectorStorageTypeOneOf2](docs/VectorStorageTypeOneOf2.md)
 - [VectorStruct](docs/VectorStruct.md)
 - [VectorsConfig](docs/VectorsConfig.md)
 - [VectorsConfigDiff](docs/VectorsConfigDiff.md)
 - [WalConfig](docs/WalConfig.md)
 - [WalConfigDiff](docs/WalConfigDiff.md)
 - [WebApiTelemetry](docs/WebApiTelemetry.md)
 - [WithLookup](docs/WithLookup.md)
 - [WithLookupInterface](docs/WithLookupInterface.md)
 - [WithPayloadInterface](docs/WithPayloadInterface.md)
 - [WithVector](docs/WithVector.md)
 - [WriteOrdering](docs/WriteOrdering.md)


## Documentation For Authorization


## api-key

- **Type**: API key
- **API key parameter name**: api-key
- **Location**: HTTP header


## bearerAuth

- **Type**: Bearer authentication


## Author

andrey@vasnetsov.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in qdrant_openapi.apis and qdrant_openapi.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from qdrant_openapi.api.default_api import DefaultApi`
- `from qdrant_openapi.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import qdrant_openapi
from qdrant_openapi.apis import *
from qdrant_openapi.models import *
```

